﻿using DressAtelierContracts.BindingModels;
using DressAtelierContracts.SearchModels;
using DressAtelierContracts.StorageContracts;
using DressAtelierContracts.ViewModels;
using DressAtelierFileImplement.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace DressAtelierFileImplement.Implements
{
    public class ClientStorage : IClientStorage
    {
        private readonly DataFileSingleton _source;

        public ClientStorage()
        {
            _source = DataFileSingleton.GetInstance();
        }
        public ClientViewModel? Insert(ClientBindingModel model)
        {
            model.ID = _source.Clients.Count > 0 ? _source.Clients.Max(client => client.ID) + 1 : 1;
            var newClient = Client.Create(model);
            if(newClient == null) { return null; }
            _source.Clients.Add(newClient);
            _source.SaveClients();
            return newClient.GetViewModel;
        }

        public ClientViewModel? Update(ClientBindingModel model)
        {
            var client = _source.Clients.FirstOrDefault(x => x.ID == model.ID);
            if(client == null) { return null; };
            client.Update(model);
            _source.SaveClients();
            return client.GetViewModel;
        }
        public ClientViewModel? Delete(ClientBindingModel model)
        {
            var client = _source.Clients.FirstOrDefault(client => client.ID == model.ID);
            if(client == null) { return null; }
            _source.Clients.Remove(client);
            _source.SaveClients();
            return client.GetViewModel;
        }

        public ClientViewModel? GetElement(ClientSearchModel model)
        {
            if(string.IsNullOrEmpty(model.Email) && !model.ID.HasValue) { return null; }

            return _source.Clients.FirstOrDefault(x => (!(string.IsNullOrEmpty(model.Email)) && model.Email == x.Email) || (model.ID.HasValue && model.ID == x.ID))?.GetViewModel;
        }

        public List<ClientViewModel> GetFilteredList(ClientSearchModel model)
        {
            if (string.IsNullOrEmpty(model.Email)) { return new(); }
            return _source.Clients.Where(x => x.Email.Equals(model.Email)).Select(x => x.GetViewModel).ToList();
        }

        public List<ClientViewModel> GetFullList()
        {
            return _source.Clients.Select(x => x.GetViewModel).ToList();
        }
 
    }
}
