using DressAtelierBusinessLogic.BusinessLogic;
using DressAtelierBusinessLogic.OfficePackage;
using DressAtelierBusinessLogic.OfficePackage.Implements;
using DressAtelierContracts.BusinessLogicContracts;
using DressAtelierContracts.StorageContracts;
using DressAtelierDatabaseImplement.Implements;
using DressAtelierDatabaseImplementation.Implements;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using NLog.Extensions.Logging;

namespace SewingDresses
{
    internal static class Program
    {
        private static ServiceProvider? _serviceProvider;
        public static ServiceProvider? ServiceProvider => _serviceProvider;

        /// <summary>
        ///  The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            // To customize application configuration such as set high DPI settings or default font,
            // see https://aka.ms/applicationconfiguration.
            ApplicationConfiguration.Initialize();
            var services = new ServiceCollection();
            ConfigureServices(services);
            _serviceProvider = services.BuildServiceProvider();
            Application.Run(_serviceProvider.GetRequiredService<FormMain>());
        }

        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddLogging(option =>
            {
                option.SetMinimumLevel(LogLevel.Information);
                option.AddNLog("nlog.config");
            });
            services.AddTransient<IMaterialStorage, MaterialStorage>();
            services.AddTransient<IOrderStorage, OrderStorage>();
            services.AddTransient<IDressStorage, DressStorage>();
            services.AddTransient<IClientStorage, ClientStorage>();

            services.AddTransient<IMaterialLogic, MaterialLogic>();
            services.AddTransient<IOrderLogic, OrderLogic>();
            services.AddTransient<IDressLogic, DressLogic>();
            services.AddTransient<IReportLogic, ReportLogic>();
            services.AddTransient<IClientLogic, ClientLogic>();

            services.AddTransient<AbstractSaveToExcel, SaveToExcel>();
            services.AddTransient<AbstractSaveToWord, SaveToWord>();
            services.AddTransient<AbstractSaveToPdf, SaveToPdf>();

            services.AddTransient<FormMain>();
            services.AddTransient<FormMaterial>();
            services.AddTransient<FormMaterials>();
            services.AddTransient<FormOrderCreation>();
            services.AddTransient<FormDress>();
            services.AddTransient<FormDressMaterial>();
            services.AddTransient<FormDresses>();
            services.AddTransient<FormReportDressMaterials>();
            services.AddTransient<FormReportOrders>();
            services.AddTransient<FormClients>();
        }

    }
}